@@ -6,8 +6,9 @@ package Net::BitTorrent::Torrent::File;
     use Carp qw[carp];
     use Scalar::Util qw[blessed weaken refaddr];
     use Fcntl qw[/O_/ /SEEK/ :flock];
-    use File::Path qw[mkpath];
-    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 1; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), ($VERSION_BASE / 1000), $UNSTABLE_RELEASE);
+    use version qw[qv];
+    our $SVN = q[$Id: File.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $];
+    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 40 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
     my (@CONTENTS)
         = \
         my (%path, %torrent, %size, %index, %priority, %mode, %handle,
@@ -78,33 +79,11 @@ package Net::BitTorrent::Torrent::File;
     sub index   { return $index{refaddr +shift} }
     sub path    { return $path{refaddr +shift} }
 
-    # Accessors | Private
-    sub _percent_complete {
-        my ($self) = @_;
-        my $start = 0;
-        for my $index (0 .. $index{refaddr $self} - 1) {
-            $start += $torrent{refaddr $self}->files->[$index]->size;
-        }
-        my $end = $start + $size{refaddr $self};
-        my $piece_length
-            = $torrent{refaddr $self}->metadata(1)->{q[piece length]};
-        my $have      = 0;
-        my $_bitfield = $torrent{refaddr +shift}->bitfield;
-        $start = int($start / $piece_length);
-        $end   = int(($end / $piece_length) + 1);
-        for my $index ($start .. $end) {
-            $have += vec($_bitfield, $index, 1);
-        }
-        my $return = ($have / ($end - $start) * 100);
-        return $return > 100 ? 100 : $return;
-    }
-
-    # Methods | Private
+    # Methods | private
     sub _open {
         my ($self, $mode) = @_;
         if ((!$mode) || ($mode !~ m[^[rw]$])) {
-            carp
-                q[Net::BitTorrent::Torrent::File->_open() requires a valid mode];
+            carp q[Net::BitTorrent::Torrent::File->_open() requires a mode];
             return;
         }
         if (defined $handle{refaddr $self} and defined $mode{refaddr $self}) {
@@ -441,28 +420,30 @@ END
     sub _sysopen {
         my ($self, $mode) = @_;
         $self->_mkpath() if $mode &= O_WRONLY;
-        if (    $^O eq q[MSWin32]
-            and utf8::is_utf8($path{refaddr $self})
-            and require Win32
-            and require Win32API::File
-            and require Encode)
+        if ((    $^O eq q[MSWin32]
+             and utf8::is_utf8($path{refaddr $self})
+             and require Win32API::File
+             and require Encode
+            )
+            )
         {   Win32API::File->import(qw[:ALL]);
-            my $path = $path{refaddr $self};
-            foreach my $null (qq[\0], q[]) {
-                my $_path = $path . $null;
-                utf8::decode($_path);
+            Encode->import(qw[find_encoding encode]);
+            for my $null (qq[\0], q[]) {
                 $win32_handle{refaddr $self}
-                    = CreateFileW(Encode::encode("UTF-16LE", $_path),
-                                  (($mode &= O_WRONLY) ? GENERIC_WRITE()
-                                   : GENERIC_READ()
-                                  ),
-                                  FILE_SHARE_READ(),
-                                  [],
-                                  (($mode &= O_WRONLY) ? OPEN_ALWAYS()
-                                   : OPEN_EXISTING()
-                                  ),
-                                  FILE_ATTRIBUTE_NORMAL(),
-                                  0
+                    = CreateFileW(
+                                 encode(
+                                     q[UTF-16LE], $path{refaddr $self} . $null
+                                 ),
+                                 (($mode &= O_WRONLY) ? GENERIC_WRITE()
+                                  : GENERIC_READ()
+                                 ),
+                                 FILE_SHARE_READ(),
+                                 [],
+                                 (($mode &= O_WRONLY) ? OPEN_ALWAYS()
+                                  : OPEN_EXISTING()
+                                 ),
+                                 FILE_ATTRIBUTE_NORMAL(),
+                                 0
                     ) and last;
             }
             return if not $win32_handle{refaddr $self};
@@ -539,7 +520,7 @@ END
         return 1;
     }
 
-    sub as_string {
+    sub _as_string {
         my ($self, $advanced) = @_;
         my $dump = !$advanced ? $path{refaddr $self} : sprintf <<'END',
 Net::BitTorrent::Torrent::File
@@ -548,7 +529,6 @@ Path: %s
 Size: %d bytes
 Priority: %d
 Open mode: %s
-Complete: %3.2f%%
 
 Torrent: %s
 Index: %d of %d
@@ -561,7 +541,6 @@ END
              : $mode{refaddr $self} eq q[rw] ? q[Read/Write]
              : q[Closed]
             ),
-            $self->_percent_complete,
             $torrent{refaddr $self}->infohash, $index{refaddr $self},
             scalar(@{$torrent{refaddr $self}->files});
         return defined wantarray ? $dump : print STDERR qq[$dump\n];
@@ -664,12 +643,6 @@ object related to this file.
 
 Returns the size of the file represented by this object.
 
-=item C<as_string ( [ VERBOSE ] )>
-
-Returns a 'ready to print' dump of the  object's data structure.  If
-called in void context, the structure is printed to C<STDERR>.
-C<VERBOSE> is a boolean value.
-
 =back
 
 =head1 Author
@@ -680,7 +653,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -696,6 +669,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: File.pm 5476ff9 2009-09-07 04:37:45Z sanko@cpan.org $
+=for svn $Id: File.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $
 
 =cut
