@@ -9,13 +9,12 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
     use Socket qw[PF_INET SOMAXCONN SOCK_STREAM inet_aton pack_sockaddr_in];
     use Fcntl qw[F_SETFL O_NONBLOCK];
     use lib q[../../../../../lib];
-    use Net::BitTorrent::Util qw[:bencode :compact];
-    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 1; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), ($VERSION_BASE / 1000), $UNSTABLE_RELEASE);
+    use Net::BitTorrent::Util qw[:bencode uncompact];
+    use version qw[qv];
+    our $SVN = q[$Id: HTTP.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $];
+    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 40 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
     my (@CONTENTS)
-        = \my (%_url,   %_tier,     %resolve,
-               %_event, %_socket,   %_data_out,
-               %_peers, %_complete, %_incomplete
-        );
+        = \my (%_url, %_tier, %resolve, %_event, %_socket, %_data_out);
     my %REGISTRY;
 
     sub new {
@@ -35,30 +34,21 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
             return;
         }
         my $self = bless \$args->{q[URL]}, $class;
-        $_url{refaddr $self}        = $args->{q[URL]};
-        $_tier{refaddr $self}       = $args->{q[Tier]};
-        $_peers{refaddr $self}      = q[];
-        $_complete{refaddr $self}   = 0;
-        $_incomplete{refaddr $self} = 0;
+        $_url{refaddr $self}  = $args->{q[URL]};
+        $_tier{refaddr $self} = $args->{q[Tier]};
         weaken $_tier{refaddr $self};
         weaken($REGISTRY{refaddr $self} = $self);
         return $self;
     }
 
-    # Accessors | Public
-    sub url { my ($self) = @_; return $_url{refaddr $self}; }
-
     # Accesors | Private
     sub _socket { return $_socket{refaddr +shift}; }
     sub _tier   { return $_tier{refaddr +shift}; }
-    sub _peers  { return $_peers{refaddr +shift}; }
-    sub _client { return $_tier{refaddr +shift}->_client }
+    sub _url    { return $_url{refaddr +shift}; }
 
     # Methods | Private
     sub _announce {
         my ($self, $event) = @_;
-
-        #warn sprintf q[_announce(%s)], $event? qq['$event']:q[];
         if (defined $event) {
             if ($event !~ m[^(?:st(?:art|opp)|complet)ed$]) {
                 carp sprintf q[Invalid event for announce: %s], $event;
@@ -86,15 +76,9 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
                 : fcntl($_socket{refaddr $self}, F_SETFL, O_NONBLOCK)
             )
             )
-        {   $_tier{refaddr $self}->_torrent->_event(
-                q[tracker_failure],
-                {Tracker => $self,
-                 Reason  => sprintf(
-                     q[There was a problem making an outgoing socket non-blocking: [%d] %s],
-                     $^E, $^E
-                 )
-                }
-            );
+        {   carp
+                q[There was a problem making an outgoing socket non-blocking: ]
+                . $^E;
             return;
         }
         my $_inet_aton = inet_aton($host);
@@ -129,35 +113,35 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
         my $infohash = $_tier{refaddr $self}->_torrent->infohash;
         $infohash =~ s|(..)|\%$1|g;
         my %query_hash = (
-            q[info_hash] => $infohash,
-            q[peer_id]   => $_tier{refaddr $self}->_client->peerid(),
-            q[port]     => ($_tier{refaddr $self}->_client->_tcp_port() || 0),
-            q[uploaded] => $_tier{refaddr $self}->_torrent->uploaded(),
-            q[downloaded] => $_tier{refaddr $self}->_torrent->downloaded(),
-            q[left]       => (
-                $_tier{refaddr $self}->_torrent->metadata(1)
-                    ->{q[piece length]} * sum(
-                    split(
-                        q[],
-                        unpack(
-                            q[b*],
-                            ($_tier{refaddr $self}->_torrent->_wanted() || q[]
-                            )
-                        )
-                    )
-                    )
-            ),
-            q[key]        => $^T,
-            q[numwant]    => 200,
-            q[compact]    => 1,
-            q[no_peer_id] => 1,
-            ($_event{refaddr $self}
-             ? (q[event] => $_event{refaddr $self})
-             : ()
-            )
+               q[info_hash]  => $infohash,
+               q[peer_id]    => $_tier{refaddr $self}->_client->peerid(),
+               q[port]       => $_tier{refaddr $self}->_client->_tcp_port(),
+               q[uploaded]   => $_tier{refaddr $self}->_torrent->uploaded(),
+               q[downloaded] => $_tier{refaddr $self}->_torrent->downloaded(),
+               q[left]       => (
+                   $_tier{refaddr $self}
+                       ->_torrent->raw_data->{q[info]}{q[piece length]} * sum(
+                       split(q[],
+                             unpack(
+                                   q[b*],
+                                   ($_tier{refaddr $self}->_torrent->_wanted()
+                                        || q[]
+                                   )
+                             )
+                       )
+                       )
+               ),
+               q[key]        => $^T,
+               q[numwant]    => 200,
+               q[compact]    => 1,
+               q[no_peer_id] => 1,
+               ($_event{refaddr $self}
+                ? (q[event] => $_event{refaddr $self})
+                : ()
+               )
         );
-        my $url
-            = $path
+        my $url 
+            = $path 
             . ($path =~ m[\?] ? q[&] : q[?])
             . (join q[&],
                map { sprintf q[%s=%s], $_, $query_hash{$_} }
@@ -179,8 +163,6 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
 
     sub _rw {
         my ($self, $read, $write, $error) = @_;
-
-#Carp::cluck sprintf q[%s->_rw(%d, %d, %d)], __PACKAGE__, $read, $write, $error;
         my ($actual_read, $actual_write) = (0, 0);
         return if not defined $_tier{refaddr $self}->_client;
         if ($error) {
@@ -188,7 +170,7 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
             shutdown($_socket{refaddr $self}, 2);
             close $_socket{refaddr $self};
             $_tier{refaddr $self}->_client->_schedule(
-                {   Time => time + 30,
+                {   Time => time + 300,
                     Code => sub {
                         my ($s) = @_;
                         $_tier{refaddr $s}->_shuffle;
@@ -273,9 +255,13 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
                         );
                     }
                     else {
-                        $_peers{refaddr $self}      = $data->{q[peers]};
-                        $_complete{refaddr $self}   = $data->{q[complete]};
-                        $_incomplete{refaddr $self} = $data->{q[incomplete]};
+                        $_tier{refaddr $self}
+                            ->_torrent->_append_compact_nodes(
+                                                           $data->{q[peers]});
+                        $_tier{refaddr $self}
+                            ->_set_complete($data->{q[complete]});
+                        $_tier{refaddr $self}
+                            ->_set_incomplete($data->{q[incomplete]});
                         $_tier{refaddr $self}
                             ->_torrent->_event(q[tracker_success],
                                         {Tracker => $self, Payload => $data});
@@ -320,7 +306,7 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
         return ($actual_read, $actual_write);
     }
 
-    sub as_string {
+    sub _as_string {
         my ($self, $advanced) = @_;
         my $dump = !$advanced ? $$self : sprintf <<'END',
 Net::BitTorrent::Torrent::Tracker::HTTP
@@ -370,22 +356,6 @@ constructor should not be used directly.
 
 =back
 
-=head1 Methods
-
-=over
-
-=item C<url ( )>
-
-Returns the related HTTP URL according to the original metadata.
-
-=item C<as_string ( [ VERBOSE ] )>
-
-Returns a 'ready to print' dump of the  object's data structure.  If
-called in void context, the structure is printed to C<STDERR>.
-C<VERBOSE> is a boolean value.
-
-=back
-
 =head1 BUGS/TODO
 
 =over 4
@@ -404,7 +374,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -420,6 +390,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: HTTP.pm 5476ff9 2009-09-07 04:37:45Z sanko@cpan.org $
+=for svn $Id: HTTP.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $
 
 =cut
