@@ -8,15 +8,15 @@ package Net::BitTorrent::Torrent::Tracker::UDP;
     use List::Util qw[sum];
     use Socket qw[inet_aton pack_sockaddr_in];
     use lib q[../../../../../lib];
-    use Net::BitTorrent::Util qw[:compact];
-    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 1; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), ($VERSION_BASE / 1000), $UNSTABLE_RELEASE);
+    use Net::BitTorrent::Util qw[uncompact];
+    use version qw[qv];
+    our $SVN = q[$Id: UDP.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $];
+    our $UNSTABLE_RELEASE = 3; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 40 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
     my %REGISTRY = ();
-    my @CONTENTS = \my (%_url,                  %_tier,
-                        %_tid,                  %_cid,
-                        %_outstanding_requests, %_packed_host,
-                        %_event,                %_peers,
-                        %_complete,             %_incomplete
-    );
+    my @CONTENTS
+        = \
+        my (%_url, %_tier, %_tid, %_cid, %_outstanding_requests,
+            %_packed_host, %_event);
 
     sub new {
         my ($class, $args) = @_;
@@ -48,25 +48,19 @@ package Net::BitTorrent::Torrent::Tracker::UDP;
         else { $packed_host = inet_aton($host) }
         $_packed_host{refaddr $self}
             = pack_sockaddr_in($port, inet_aton($host));
-        $_url{refaddr $self}        = $args->{q[URL]};
-        $_event{refaddr $self}      = q[];
-        $_tier{refaddr $self}       = $args->{q[Tier]};
-        $_peers{refaddr $self}      = q[];
-        $_complete{refaddr $self}   = 0;
-        $_incomplete{refaddr $self} = 0;
-        $_tid{refaddr $self}        = int(rand() * 26**5);
+        $_url{refaddr $self}   = $args->{q[URL]};
+        $_event{refaddr $self} = q[];
+        $_tier{refaddr $self}  = $args->{q[Tier]};
+        $_tid{refaddr $self}   = int(rand() * 26**5);
         weaken $_tier{refaddr $self};
         weaken($REGISTRY{refaddr $self} = $self);
         return $self;
     }
 
-    # Accessors | Public
-    sub url { my ($self) = @_; return $_url{refaddr $self}; }
-
     # Accessors | Private
     sub _packed_host { return $_packed_host{refaddr +shift} }
     sub _tier        { return $_tier{refaddr +shift}; }
-    sub _peers       { return $_peers{refaddr +shift}; }
+    sub _url         { return $_url{refaddr +shift}; }
     sub _client      { return $_tier{refaddr +shift}->_client }
 
     # Methods | Private
@@ -100,17 +94,17 @@ package Net::BitTorrent::Torrent::Tracker::UDP;
                 $self->_client->peerid(),
                 ___pack64($_tier{refaddr $self}->_torrent->downloaded()),
                 ___pack64(
-                     $_tier{refaddr $self}->_torrent->metadata(1)
-                         ->{q[piece length]} * sum(
-                         split(q[],
-                               unpack(
+                   $_tier{refaddr $self}
+                       ->_torrent->raw_data->{q[info]}{q[piece length]} * sum(
+                       split(q[],
+                             unpack(
                                    q[b*],
                                    ($_tier{refaddr $self}->_torrent->_wanted()
                                         || q[]
                                    )
-                               )
-                         )
-                         )
+                             )
+                       )
+                       )
                 ),
                 ___pack64($_tier{refaddr $self}->_torrent->uploaded()),
                 (  $_event{refaddr $self} eq q[completed] ? 1
@@ -118,8 +112,7 @@ package Net::BitTorrent::Torrent::Tracker::UDP;
                  : $_event{refaddr $self} eq q[stopped]   ? 3
                  : 0
                 ),
-                0, $^T, 200, $self->_client->_tcp_port
-                || 0;
+                0, $^T, 200, $self->_client->_tcp_port;
             $_outstanding_requests{refaddr $self}{$tid} = {Timestamp => time,
                                                            Attempt   => 1,
                                                            Packet => $packet,
@@ -212,9 +205,10 @@ package Net::BitTorrent::Torrent::Tracker::UDP;
             if (length($data) >= 20) {
                 my ($min_interval, $leeches, $seeds, $peers)
                     = unpack(q[N N N a*], $packet);
-                $_peers{refaddr $self}      = $peers;
-                $_complete{refaddr $self}   = $seeds;
-                $_incomplete{refaddr $self} = $leeches;
+                $_tier{refaddr $self}
+                    ->_torrent->_append_compact_nodes($peers);
+                $_tier{refaddr $self}->_set_complete($seeds);
+                $_tier{refaddr $self}->_set_incomplete($leeches);
                 $_tier{refaddr $self}->_torrent->_event(
                                             q[tracker_success],
                                             {Tracker => $self,
@@ -275,7 +269,7 @@ package Net::BitTorrent::Torrent::Tracker::UDP;
         return $_tid{refaddr $self};
     }
 
-    sub as_string {
+    sub _as_string {
         my ($self, $advanced) = @_;
         my $dump = !$advanced ? $$self : sprintf <<'END',
 Net::BitTorrent::Torrent::Tracker::UDP
@@ -346,22 +340,6 @@ constructor should not be used directly.
 
 =back
 
-=head1 Methods
-
-=over
-
-=item C<url ( )>
-
-Returns the related UDP 'URL' according to the original metadata.
-
-=item C<as_string ( [ VERBOSE ] )>
-
-Returns a 'ready to print' dump of the  object's data structure.  If
-called in void context, the structure is printed to C<STDERR>.
-C<VERBOSE> is a boolean value.
-
-=back
-
 =head1 BUGS/TODO
 
 =over 4
@@ -396,7 +374,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -412,6 +390,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: UDP.pm 5476ff9 2009-09-07 04:37:45Z sanko@cpan.org $
+=for svn $Id: UDP.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $
 
 =cut
