@@ -1,102 +1,100 @@
-#!perl -w -I../lib
+#!/usr/bin/perl
 use strict;
 use warnings;
 use Getopt::Long;
 use Pod::Usage;
 use Carp qw[croak carp];
 use Time::HiRes qw[sleep];
+use lib q[../lib];
 use Net::BitTorrent::Protocol qw[:types];
-use Net::BitTorrent::Util qw[:bencode];
-use Net::BitTorrent::Torrent qw[:status];
 use Net::BitTorrent;
 $|++;
-my ($dir, $chk, $int, $VERSION, $port, $ver, @tor, %opts)
-    = (q[./], 1, 1, 0.050);
-GetOptions(
-    q[check!]      => \$chk,
-    q[directory:s] => \$dir,
-    q[help|?]      => sub {
-        pod2usage({-verbose  => 99,
-                   -sections => q[Synopsis|Options|Author]
-                  }
-        );
-    },
-    q[options=s%] => sub { $opts{$_[1]} = $_[2] if $_[1] =~ m[^_set] },
-    q[port:i]     => \$port,
-    q[torrent=s@] => \@tor,
-    q[version] => sub { exit printf qq[$0 v$VERSION] },
-) || pod2usage(2);
+my ($VERSION, $dir, $chk, $int, $help, $port, $ver, @tor, %opts)
+    = (sprintf(q[%.3f], (qw$Rev: 40 $)[1] / 1000), q[./], 1, 1, 0);
+GetOptions(q[help|?]       => \$help,
+           q[torrent|t=s@] => \@tor,
+           q[port:i]       => \$port,
+           q[directory:s]  => \$dir,
+           q[check!]       => \$chk,
+           q[version]      => \$ver,
+           q[options=s%]   => sub { $opts{$_[1]} = $_[2]; }    # private
+) or pod2usage(2);
 @tor = grep {-f} @tor, @ARGV;
-pod2usage({-verbose  => 99,
-           -sections => q[Synopsis|Author],
+$ver && exit printf <<VER, $0, $VERSION, $Net::BitTorrent::VERSION, $^V, $^O;
+%s version %.3f
+Net::BitTorrent version %s
+Perl version %vd on %s
+VER
+pod2usage({-verbose => 99,
+           -sections =>
+               q[NAME|Description|Synopsis|Options|Author|License and Legal],
           }
-) if !@tor;
+    )
+    if $help
+        or !@tor;
 my $bt = new Net::BitTorrent({LocalPort => $port})
-    or croak q[Failed to create Net::BitTorrent object];
-
-sub piece_status {
-    my $args   = pop;
-    my $t      = $args->{q[Torrent]};
-    my $have   = grep {$_} split //, unpack q[b*], $t->bitfield;
-    my $wanted = grep {$_} split //, unpack q[b*], $t->_wanted;
-    return printf qq[%s: %04d|%s|%4d/%4d|% 3.2f%%\r],
-        pop, $args->{q[Index]}, $t->as_string(), $have, $t->piece_count,
-        100 - ($wanted / $t->piece_count * 100);
-}
-
-sub trans_status {
-    printf qq[%-10s p:%15s:%-5d i:%4d o:%7d l:%5d  \r],
-        shift, $_[0]->{q[Peer]}->_host, $_[0]->{q[Peer]}->_port,
-        $_[0]->{q[Payload]}{q[Index]},
-        $_[0]->{q[Payload]}{q[Offset]},
-        $_[0]->{q[Payload]}{q[Length]};
-}
-
-sub save {
-    for my $torrent (values %{$bt->torrents || {}}) {
-        open my $TORRENT, q[>], $torrent->path or next;
-        syswrite($TORRENT, $torrent->resume_data) or next;
-    }
-}
-$SIG{q[INT]} = sub {
-    save();
-    $int = $int + 3 > time ? exit : time;
-    print join qq[\n], map { $_->as_string(1) } $bt, values %{$bt->torrents};
-};
-END { save if $bt }
+    or croak sprintf q[Failed to create Net::BitTorrent object (%s)], $^E;
 $bt->on_event(
     q[incoming_packet],
     sub {
-        trans_status(q[REJECTED], $_[1]) if $_[1]{q[Type]} eq REJECT;
-        trans_status(q[RECEIVED], $_[1]) if $_[1]{q[Type]} eq PIECE;
+        trans_status(q[REJECTED], $_[1]) if $_[1]->{q[Type]} eq REJECT;
+        trans_status(q[RECEIVED], $_[1]) if $_[1]->{q[Type]} eq PIECE;
     }
 );
 $bt->on_event(
     q[outgoing_packet],
     sub {
-        trans_status(q[REQUESTING], $_[1]) if $_[1]{q[Type]} eq REQUEST;
-        trans_status(q[CANCELING],  $_[1]) if $_[1]{q[Type]} eq CANCEL;
-        trans_status(q[SENDING],    $_[1]) if $_[1]{q[Type]} eq PIECE;
+        trans_status(q[REQUESTING], $_[1]) if $_[1]->{q[Type]} eq REQUEST;
+        trans_status(q[CANCELING ], $_[1]) if $_[1]->{q[Type]} eq CANCEL;
+        trans_status(q[SENDING   ], $_[1]) if $_[1]->{q[Type]} eq PIECE;
     }
 );
 $bt->on_event(q[piece_hash_pass], sub { piece_status(q[pass], $_[1]); });
 $bt->on_event(q[piece_hash_fail], sub { piece_status(q[fail], $_[1]); });
 for my $path (@tor) {
-    my $obj = $bt->add_torrent({Path    => $path,
-                                BaseDir => $dir,
-                                Status  => ($chk ? START_AFTER_CHECK : ())
-                               }
-    ) || next;
-    $obj->status & CHECKED || $obj->hashcheck;
+    stat print qq[Loading '$path'...];
+    my $obj = $bt->add_torrent({Path => $path, BaseDir => $dir})
+        || carp(qq[Cannot load '$path': $^E]) && next;
+    print qq[Hash checking...\n] and $obj->hashcheck if $chk;
     printf qq[Loaded '$path' [%s...%s%s]\n],
-        $obj->infohash =~ m[^(.{4}).+(.{4})$], $obj->private ? q[] : q[|DHT];
-}
-$bt->on_event(q[file_error], sub { carp $_[1]->{q[Message]} });
-for my $obj ($bt, values %{$bt->torrents}) {
-    for my $opt (keys %opts) { $obj->$opt($opts{$opt}) if $obj->can($opt); }
+        ($obj->infohash =~ (m[^(.{4}).+(.{4})$])),
+        ($obj->private ? q[|No DHT] : q[]);
+    for (keys %opts) { $obj->$_($opts{$_}) if $obj->can($_); }
 }
+$SIG{q[INT]} = sub {
+    $int = ($int + 1 > time) ? exit : time;
+    print qq[\n--> Press Ctrl-C again within 3 seconds to exit <--\n]
+        . $bt->_as_string(1)
+        . (join q[\n], map { $_->_as_string(1) } values %{$bt->torrents});
+};
+for (keys %opts) { $bt->$_($opts{$_}) if $bt->can($_); }
 $bt->do_one_loop(0.25) && sleep(0.50) while 1;
 
+sub piece_status {
+    my ($msg, $args) = @_;
+    my $torrent = $args->{q[Torrent]};
+    return printf qq[%s: %04d|%s|%4d/%4d|% 3.2f%%\r],
+        $msg, $args->{q[Index]}, $torrent->_as_string(),
+        (scalar grep {$_} split q[], unpack(q[b*], $torrent->bitfield)),
+        $torrent->piece_count,
+        (((  (scalar grep {$_} split q[], unpack q[b*], $torrent->bitfield)
+           / ($torrent->piece_count)
+          )
+         ) * 100
+        );
+}
+
+sub trans_status {
+    printf(qq[%-10s p:%15s:%-5d i:%4d o:%7d l:%5d  \r],
+           shift,
+           $_[0]->{q[Peer]}->_host,
+           $_[0]->{q[Peer]}->_port,
+           $_[0]->{q[Payload]}->{q[Index]},
+           $_[0]->{q[Payload]}->{q[Offset]},
+           $_[0]->{q[Payload]}->{q[Length]}
+    );
+}
+
 =pod
 
 =head1 NAME
@@ -123,9 +121,6 @@ client.
    -?     --help        Display full documentation
    --version            Display version information
 
-To get client-wide progress updates, press C<Ctrl+C>.  For more, see
-perldoc.
-
 =head1 Options
 
 =over 8
@@ -165,16 +160,16 @@ upload bandwidth limit...
 
 You may pass several C<--options> parameters.
 
+=item B<--help>
+
+Print the manual page and exit.
+
 =item B<--version>
 
 Guess.
 
 =back
 
-=head1 See Also
-
-For more examples, see the files under the C</tatoeba/> directory.
-
 =head1 Author
 
 Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
@@ -199,6 +194,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: bittorrent.pl a7a7e9d 2009-02-09 04:49:58Z sanko@cpan.org $
+=for svn $Id: bittorrent.pl 40 2008-12-02 04:25:26Z sanko@cpan.org $
 
 =cut
